__copyright__ = "Copyright 2016-2018, Netflix, Inc."
__license__ = "Apache, Version 2.0"

# Note, version doesn't have to be hard-coded like this, it can also be determined programmatically
__version__ = "0.7.0"
